<?php
/** 
 * 
 * @author Vee W.
 * @license http://opensource.org/licenses/MIT
 * 
 */


namespace System\Libraries\Db;

/**
 * The database class that works on Doctrine's Dbal class.
 */
class Db
{


    /**
     * Doctrine Dbal driver manager
     * @var \Doctrine\DBAL\Connection 
     */
    public $Conn;

    /**
     * Table prefix.
     * @var string Return table prefix in config file. you can get it by calling to <code>$db->getTableName('table_name');</code>
     */
    protected $table_prefix;


    public function __construct()
    {
        if ($this->Conn == null) {
            $this->connect();
        }
    }// __construct


    /**
     * close Doctrine Dbal and ORM connection and reset everything to default.
     */
    public function close()
    {
        $this->Conn->close();
        if (function_exists('gc_collect_cycles')) {
            gc_collect_cycles();
        }

        $this->Conn = '';
        $this->table_prefix = '';
    }// close


    /**
     * connect or prepare db connection.
     * 
     * @param array $db_config array config for override the default configuration.
     */
    private function connect(array $db_config = [])
    {
        if ($this->Conn != null) {
            return;
        }

        $db_bootstrap = new \System\Libraries\Db\Bootstrap($db_config);
        $this->Conn = $db_bootstrap->Conn;
        unset($db_bootstrap);

        // set table prefix property.
        if (empty($db_config)) {
            $config = new \System\Libraries\Config();
            $this->table_prefix = $config->get('table_prefix', 'db', 'adt_');
            unset($config);
        } else {
            if (is_array($db_config) && array_key_exists('table_prefix', $db_config)) {
                $this->table_prefix = $db_config['table_prefix'];
            }
        }
    }// connect


    /**
     * Get table name.
     * 
     * @param string $table_name
     * @return return table name with prefixed
     */
    public function getTableName($table_name)
    {
        return $this->table_prefix.$table_name;
    }// getTableName


    /**
     * Prepare sql statement
     * 
     * @param string $statement
     * @return \Doctrine\DBAL\Driver\Statement
     */
    public function prepare($statement)
    {
        return $this->Conn->prepare($statement);
    }// prepare


    /**
     * Start query builder.
     * 
     * @return System\Libraries\Db\DoctrineExtensions\QueryBuilder
     */
    public function queryBuilder()
    {
        return $this->Conn->createQueryBuilder();
    }// queryBuilder


    /**
     * Re-connect to db.
     * 
     * @param array $db_config array config for override the default configuration.
     */
    public function reconnect(array $db_config = [])
    {
        $this->close();

        $this->connect($db_config);
    }// reconnect


}