<?php


namespace System\Libraries;

/**
 * Remote address (IP address) class to works with get the real IP address.
 *
 * @author Vee W.
 */
class RemoteAddress
{


    /**
     * Get IP address
     * 
     * @return string Return IP address.
     */
    public function getIpAddress()
    {
        $ip = $this->getIpAddressFromProxy();

        if ($ip != null) {
            $ip .= ',';
        }

        $ip .= $this->getRealIpAddress();

        return $ip;
    }// getIpAddress


    /**
     * Get IP addresses from proxy.
     * 
     * @return string Return IP address from proxy.
     */
    protected function getIpAddressFromProxy()
    {
        if (filter_input(INPUT_SERVER, 'HTTP_CLIENT_IP', FILTER_VALIDATE_IP) !== false) {
            return filter_input(INPUT_SERVER, 'HTTP_CLIENT_IP', FILTER_VALIDATE_IP);
        } elseif (filter_input(INPUT_SERVER, 'HTTP_X_FORWARDED_FOR', FILTER_VALIDATE_IP) !== false) {
            return filter_input(INPUT_SERVER, 'HTTP_X_FORWARDED_FOR', FILTER_VALIDATE_IP);
        }
        return null;
    }// getIpAddressFromProxy


    /**
     * Get real IP address
     * 
     * @link http://stackoverflow.com/a/3003233/128761 Answer about IP address from REMOTE_ADDR and HTTP_X_FORWARDED_FOR.
     * @return string Return IP address
     */
    protected function getRealIpAddress()
    {
        return $_SERVER['REMOTE_ADDR'];
    }// getRealIpAddress


}
