<?php


namespace System\Middleware;

use \Psr\Http\Message\ServerRequestInterface;
use \Psr\Http\Message\ResponseInterface;

/**
 * Remove trailing slash from any URLs by redirect to no trailing slash URL.
 *
 * @author Vee W.
 */
class TrailingSlashRedirect
{


    /**
     * Invokable class.
     * This will be redirect any trailing slash URL to non trailing slash URL.
     * 
     * @param ServerRequestInterface $request
     * @param ResponseInterface $response
     * @param \System\Middleware\callable $next
     * @return \Psr\Http\Message\ResponseInterface
     */
    public function __invoke(ServerRequestInterface $request, ResponseInterface $response, callable $next)
    {
        $uri = $request->getUri();
        $path = $uri->getPath();
        if ($path != '/' && substr($path, -1) == '/') {
            // permanently redirect paths with a trailing slash
            // to their non-trailing counterpart
            $uri = $uri->withPath(substr($path, 0, -1));
            return $response->withRedirect((string)$uri, 301);
        }

        return $next($request, $response);
    }// __invoke


}
