<?php
/**
 * @package PHP API test
 * @version 0.1a
 * @author Vee W.
 * @license http://opensource.org/licenses/MIT MIT
 */


// defined some constants that will be useful. --------------------------------------------
if (!defined('APP_ENV')) {
    // define app environment.
    //  value can be production, test, development. 
    // config values will be auto detect by order if the files in these env were not found.
    define('APP_ENV', 'development');
}
if (!defined('ROOT_PATH')) {
    define('ROOT_PATH', __DIR__);
}
if (!defined('STORAGE_PATH')) {
    define('STORAGE_PATH', ROOT_PATH . DIRECTORY_SEPARATOR . 'Storage');
}
// end define constants ---------------------------------------------------------------------


// require Composer autoload.
require __DIR__ . DIRECTORY_SEPARATOR . 'System' . DIRECTORY_SEPARATOR . 'vendor' . DIRECTORY_SEPARATOR . 'autoload.php';


// get the configurations --------------------------------------------------------------------
$Config = new System\Libraries\Config();
$app_config = [
    'settings' => [],
];
$app_config['settings'] = array_merge($app_config['settings'], ['displayErrorDetails' => $Config->get('displayErrorDetails', 'app', false)]);
unset($Config);
// end get the configurations ---------------------------------------------------------------


// begins Slim app
$app_config['Db'] = new System\Libraries\Db\Db();
$container = new \Slim\Container($app_config);
$App = new \Slim\App($container);
unset($app_config, $container);


// middle ware -------------------------------------------------------------------------------
$App->add(new System\Middleware\TrailingSlashRedirect());
// end middle ware --------------------------------------------------------------------------


// routes here. -------------------------------------------------------------------------------
$App->any('/', '\Modules\Home\Controllers\IndexController:indexAction');// home page. it should accept any method.
$App->post('/add', '\Modules\Home\Controllers\IndexController:addAction');
$App->get('/getData', '\Modules\Home\Controllers\IndexController:getDataAction');
$App->patch('/edit/{id}', '\Modules\Home\Controllers\IndexController:editAction');
$App->post('/editUpload/{id}', '\Modules\Home\Controllers\IndexController:editUploadAction');// due to upload file via put or patch method **with input form data** is very hard or impossible, i have to split the process of upload the file to this one.
$App->delete('/deleteItems', '\Modules\Home\Controllers\IndexController:deleteItemsAction');
// end routes here ---------------------------------------------------------------------------


// initialize the application.
$App->run();